@@ -105,6 +105,8 @@ class ONTSWAP(Base):
     new_siteid = Column(Integer, nullable=False)
     new_sitename = Column(String(length=256), nullable=False)
     new_site_shortname = Column(String(length=12), nullable=False)
+    cust_id = Column(String(length=64), nullable=False, comment='Billing system Customer ID')
+    subs_id = Column(String(length=64), nullable=False, comment='Billing system Subscription ID')
     old_ucr = Column(String(length=64), nullable=False)
     old_ont_register_datetime = Column(DateTime)
     old_service_provision_datetime = Column(DateTime)
